;; Generated package description from vc-sapling.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "vc-sapling" "0.2.1.0.20260820.0" "VC backend for Sapling" '((emacs "26.1") (sapling "0.2.0")) :commit "d1edae122831e39ea5e6c67e26a5f2efd218bf06" :authors '(("Swithin Chan" . "swithinchan@yahoo.com.hk")) :maintainer '("Swithin Chan" . "swithinchan@yahoo.com.hk") :keywords '("tools" "vc") :url "https://github.com/swithinchan/vc-sapling/")
